/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.classifiers.data;

/**
 * This is an interface for all kinds of DataPoints. We model three types of
 * DataPoints here:
 * <ul><li>CoreDataPoint to classify a potential core of a relation before
 * trying to build a relation out of it.</li>
 * <li>CoreSlotCombinationDataPoint to classify if a given slot instances can be
 * aggregated to a relation with the given core instance.</li>
 * <li>RelationDataPoint to classify full relations given the results of the
 * core classifier and all slot classifiers.</li></ul>
 * Each type of DataPoint uses different features.
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public interface DataPoint {

	/**
	 * Return the FeatureMap for this DataPoint.
	 *
	 * @param dict the FeatureDictionary that shall be used.
	 * @param addFeaturesToDictionary this should be set to true during
	 * training, because then unknown features should be added to the
	 * FeatureDictionary. Outside training this should be set to false because
	 * then we want to treat every unknown feature as zero implicitly.
	 * @return the FeatureMap for this DataPoint.
	 */
	public FeatureMap getFeatureRepresentation(FeatureDictionary dict, boolean addFeaturesToDictionary);

}
